@@ -35,7 +35,7 @@
 #          David LIPSZYC <davidlipszyc@gmail.com>
 #          Guillaume Pellerin <yomguy@parisson.com>
 
-import re
+import re, os, random
 import mimetypes
 from django.contrib.auth.models import User
 from django.utils.translation import ugettext_lazy as _
@@ -50,21 +50,49 @@ from telemeta.models.instrument import *
 from telemeta.models.enum import *
 from telemeta.models.language import *
 from telemeta.models.format import *
+from telemeta.util.kdenlive.session import *
 from django.db import models
+from django.conf import settings
 
-collection_published_code_regex   = '[A-Za-z0-9._-]*'
-collection_unpublished_code_regex = '[A-Za-z0-9._-]*'
-collection_code_regex             = '(?:%s|%s)' % (collection_published_code_regex,
-                                                    collection_unpublished_code_regex)
 
-item_published_code_regex    = '[A-Za-z0-9._-]*'
-item_unpublished_code_regex  = '[A-Za-z0-9._-]*'
-item_code_regex              = '(?:%s|%s)' % (item_published_code_regex, item_unpublished_code_regex)
+# Special code regex of collections for the branch
+collection_published_code_regex = getattr(settings, 'COLLECTION_PUBLISHED_CODE_REGEX', '[A-Za-z0-9._-]*')
+collection_unpublished_code_regex = getattr(settings, 'COLLECTION_UNPUBLISHED_CODE_REGEX', '[A-Za-z0-9._-]*')
 
-PUBLIC_ACCESS_CHOICES = (('none', 'none'), ('metadata', 'metadata'), ('full', 'full'))
+# CREM
+#collection_published_code_regex   = 'CNRSMH_E_[0-9]{4}(?:_[0-9]{3}){2}'
+#collection_unpublished_code_regex = 'CNRSMH_I_[0-9]{4}_[0-9]{3}'
+
+collection_code_regex = '(?:%s|%s)' % (collection_published_code_regex,
+                                       collection_unpublished_code_regex)
+
+item_published_code_regex = getattr(settings, 'ITEM_PUBLISHED_CODE_REGEX', '[A-Za-z0-9._-]*')
+item_unpublished_code_regex = getattr(settings, 'ITEM_UNPUBLISHED_CODE_REGEX', '[A-Za-z0-9._-]*')
+
+# CREM
+# item_published_code_regex    = collection_published_code_regex + '(?:_[0-9]{2,3}){1,2}'
+# item_unpublished_code_regex  = collection_unpublished_code_regex + '_[0-9]{2,3}(?:_[0-9]{2,3}){0,2}'
+
+item_code_regex = '(?:%s|%s)' % (item_published_code_regex, item_unpublished_code_regex)
+
+PUBLIC_ACCESS_CHOICES = (('none', _('none')), ('metadata', _('metadata')),
+                         ('mixed', _('mixed')), ('full', _('full')))
+
+ITEM_PUBLIC_ACCESS_CHOICES = (('none', _('none')), ('metadata', _('metadata')),
+                         ('full', _('full')))
+
+ITEM_TRANSODING_STATUS = ((0, _('broken')), (1, _('pending')), (2, _('processing')),
+                         (3, _('done')), (5, _('ready')))
 
 mimetypes.add_type('video/webm','.webm')
 
+app_name = 'telemeta'
+
+
+def get_random_hash():
+    hash = random.getrandbits(64)
+    return "%016x" % hash
+
 
 class MediaResource(ModelCore):
     "Base class of all media objects"
@@ -95,7 +123,6 @@ class MediaBaseResource(MediaResource):
     title                 = CharField(_('title'), required=True)
     description           = CharField(_('description'))
     code                  = CharField(_('code'), unique=True, required=True)
-    reference             = CharField(_('reference'), unique=True, null=True)
     public_access         = CharField(_('public access'), choices=PUBLIC_ACCESS_CHOICES,
                                       max_length=16, default="metadata")
 
@@ -140,13 +167,19 @@ class MediaRelated(MediaResource):
                     is_url_image = True
         return 'image' in self.mime_type or is_url_image
 
-    def save(self, force_insert=False, force_update=False):
+    def save(self, force_insert=False, force_update=False, author=None):
         super(MediaRelated, self).save(force_insert, force_update)
 
     def set_mime_type(self):
         if self.file:
             self.mime_type = mimetypes.guess_type(self.file.path)[0]
 
+    def is_kdenlive_session(self):
+        if self.file:
+            return '.kdenlive' in self.file.path
+        else:
+            return False
+
     def __unicode__(self):
         if self.title and not re.match('^ *N *$', self.title):
             title = self.title
@@ -193,8 +226,9 @@ class MediaCollection(MediaResource):
     booklet_author        = CharField(_('author of published notice'))
     external_references   = TextField(_('bibliographic references'))
     doctype_code          = IntegerField(_('document type'))
-    public_access         = CharField(_('public access'), choices=PUBLIC_ACCESS_CHOICES,
+    public_access         = CharField(_('access status'), choices=PUBLIC_ACCESS_CHOICES,
                                       max_length=16, default="metadata")
+    auto_period_access    = BooleanField(_('automatic access after a rolling period'), default=True)
     legal_rights          = WeakForeignKey('LegalRight', related_name="collections",
                                            verbose_name=_('legal rights'))
 
@@ -348,10 +382,11 @@ class MediaItem(MediaResource):
 
     # Legal mentions
     organization          = WeakForeignKey('Organization', verbose_name=_('organization'))
-    public_access         = CharField(_('public access'), choices=PUBLIC_ACCESS_CHOICES,
+    public_access         = CharField(_('access status'), choices=ITEM_PUBLIC_ACCESS_CHOICES,
                                       max_length=16, default="metadata")
     depositor             = CharField(_('depositor'))
     rights                = WeakForeignKey('Rights', verbose_name=_('rights'))
+    auto_period_access    = BooleanField(_('automatic access after a rolling period'), default=True)
 
     # Archiving data
     code                  = CharField(_('code'), unique=True, blank=True)
@@ -368,6 +403,7 @@ class MediaItem(MediaResource):
     external_references   = TextField(_('published references'))
     copied_from_item      = WeakForeignKey('self', related_name="copies",
                                            verbose_name=_('copy of'))
+    mimetype              = CharField(_('mime type'), max_length=255, blank=True)
 
     # Media
     file                  = FileField(_('file'), upload_to='items/%Y/%m/%d',
@@ -391,8 +427,16 @@ class MediaItem(MediaResource):
 
     @property
     def mime_type(self):
-        if self.file:
-            return mimetypes.guess_type(self.file.path)[0]
+        if not self.mimetype:
+            if self.file:
+                if os.path.exists(self.file.path):
+                    self.mimetype = mimetypes.guess_type(self.file.path)[0]
+                    self.save()
+                    return self.mimetype
+                else:
+                    return 'none'
+            else:
+                return 'none'
         else:
             return _('none')
 
@@ -414,10 +458,10 @@ class MediaItem(MediaResource):
             return True
         return False
 
-    #def clean(self):
-        #if self.code and not self.is_valid_code(self.code):
-            #raise ValidationError("%s is not a valid item code for collection %s"
-                                        #% (self.code, self.collection.code))
+    def clean(self):
+        if self.code and not self.is_valid_code(self.code):
+            raise ValidationError("%s is not a valid item code for collection %s"
+                                        % (self.code, self.collection.code))
 
     def save(self, force_insert=False, force_update=False):
         super(MediaItem, self).save(force_insert, force_update)
@@ -461,6 +505,23 @@ class MediaItemRelated(MediaRelated):
 
     item            = ForeignKey('MediaItem', related_name="related", verbose_name=_('item'))
 
+    def save(self, force_insert=False, force_update=False, using=False):
+        super(MediaItemRelated, self).save(force_insert, force_update)
+
+    def parse_markers(self, **kwargs):
+        # Parse KDEnLive session
+        if self.file:
+            if self.is_kdenlive_session():
+                session = KDEnLiveSession(self.file.path)
+                markers = session.markers(**kwargs)
+                for marker in markers:
+                    m = MediaItemMarker(item=self.item)
+                    m.public_id = get_random_hash()
+                    m.time = float(marker['time'])
+                    m.title = marker['comment']
+                    m.save()
+                return markers
+
     class Meta(MetaCore):
         db_table = 'media_item_related'
         verbose_name = _('item related media')
@@ -559,20 +620,22 @@ class PlaylistResource(ModelCore):
 
 
 class MediaItemMarker(MediaResource):
-    "2D marker object : text value vs. time"
+    "2D marker object : text value vs. time (in seconds)"
 
     element_type = 'marker'
 
     item            = ForeignKey('MediaItem', related_name="markers", verbose_name=_('item'))
     public_id       = CharField(_('public_id'), required=True)
-    time            = FloatField(_('time'))
+    time            = FloatField(_('time (s)'))
     title           = CharField(_('title'))
     date            = DateTimeField(_('date'), auto_now=True)
     description     = TextField(_('description'))
-    author          = ForeignKey(User, related_name="markers", verbose_name=_('author'))
+    author          = ForeignKey(User, related_name="markers", verbose_name=_('author'),
+                                 blank=True, null=True)
 
     class Meta(MetaCore):
         db_table = 'media_markers'
+        ordering = ['time']
 
     def __unicode__(self):
         if self.title:
@@ -581,6 +644,42 @@ class MediaItemMarker(MediaResource):
             return self.public_id
 
 
+class MediaItemTranscoded(MediaResource):
+    "Item file transcoded"
+
+    element_type = 'transcoded item'
+
+    item            = models.ForeignKey('MediaItem', related_name="transcoded", verbose_name=_('item'))
+    mimetype        = models.CharField(_('mime_type'), max_length=255, blank=True)
+    date_added      = DateTimeField(_('date'), auto_now_add=True)
+    status          = models.IntegerField(_('status'), choices=ITEM_TRANSODING_STATUS, default=1)
+    file            = models.FileField(_('file'), upload_to='items/%Y/%m/%d', max_length=1024, blank=True)
+
+    @property
+    def mime_type(self):
+        if not self.mimetype:
+            if self.file:
+                if os.path.exists(self.file.path):
+                    self.mimetype = mimetypes.guess_type(self.file.path)[0]
+                    self.save()
+                    return self.mimetype
+                else:
+                    return 'none'
+            else:
+                return 'none'
+        else:
+            return self.mimetype
+
+    def __unicode__(self):
+        if self.item.title:
+            return self.item.title + ' - ' + self.mime_type
+        else:
+            return self.item.public_id + ' - ' + self.mime_type
+
+    class Meta(MetaCore):
+        db_table = app_name + '_media_transcoded'
+
+
 class MediaItemTranscodingFlag(ModelCore):
     "Item flag to know if the MediaItem has been transcoded to a given format"
 
