@@ -60,19 +60,19 @@ resource_view = ResourceView()
 
 # query sets for Django generic views
 all_items = { 'queryset': MediaItem.objects.enriched().order_by('code', 'old_code') }
+all_items_unpublished = { 'queryset': MediaItem.objects.filter(collection__code__contains='_I_').order_by('code', 'old_code'), }
+all_items_published = { 'queryset': MediaItem.objects.filter(collection__code__contains='_E_').order_by('code', 'old_code'), }
 all_items_sound = { 'queryset': MediaItem.objects.sound().order_by('code', 'old_code') }
 all_collections = { 'queryset': MediaCollection.objects.enriched(), }
 all_collections_unpublished = { 'queryset': MediaCollection.objects.filter(code__contains='_I_'), }
 all_collections_published = { 'queryset': MediaCollection.objects.filter(code__contains='_E_'), }
 all_collections_sound = { 'queryset': MediaCollection.objects.sound().order_by('code', 'old_code') }
-all_corpus = { 'queryset': MediaCorpus.objects.all().order_by('title') }
-all_fonds = { 'queryset': MediaFonds.objects.all().order_by('title') }
+all_corpus = { 'queryset': MediaCorpus.objects.all().order_by('code') }
+all_fonds = { 'queryset': MediaFonds.objects.all().order_by('code') }
 
 # ID's regular expressions
 export_extensions = "|".join(item_view.list_export_extensions())
 
-htdocs = os.path.dirname(__file__) + '/static/telemeta'
-
 urlpatterns = patterns('',
     url(r'^$', home_view.home, name="telemeta-home"),
 
@@ -127,6 +127,10 @@ urlpatterns = patterns('',
     url(r'^archives/markers/(?P<marker_id>[A-Za-z0-9]+)/$', item_view.item_detail, name="telemeta-item-detail-marker"),
     # FIXME: need all paths
     url(r'^items/(?P<path>[A-Za-z0-9._-s/]+)/$', redirect_to, {'url': '/archives/items/%(path)s/', 'permanent': False}, name="telemeta-item-redir"),
+    url(r'^archives/items_unpublished/$', 'django.views.generic.list_detail.object_list',
+        dict(all_items_unpublished, paginate_by=20, template_name="telemeta/mediaitem_list.html"), name="telemeta-items-unpublished"),
+    url(r'^archives/items_published/$', 'django.views.generic.list_detail.object_list',
+        dict(all_items_published, paginate_by=20, template_name="telemeta/mediaitem_list.html"), name="telemeta-items-published"),
 
     # collections
     url(r'^archives/collections/$', 'django.views.generic.list_detail.object_list',
@@ -235,6 +239,10 @@ urlpatterns = patterns('',
         + r'(?P<value_id>[0-9]+)/update/$',
         instrument_view.update_instrument_value,
         name="telemeta-instrument-record-update"),
+    url(r'^admin/instruments/'
+        + r'(?P<value_id>[0-9]+)/replace/$',
+        instrument_view.replace_instrument_value,
+        name="telemeta-instrument-record-replace"),
 
     # enumerations administration
     url(r'^admin/enumerations/(?P<enumeration_id>[0-9a-z]+)/$',
@@ -254,6 +262,10 @@ urlpatterns = patterns('',
         + r'(?P<value_id>[0-9]+)/update/$',
         admin_view.update_enumeration_value,
         name="telemeta-enumeration-record-update"),
+    url(r'^admin/enumerations/(?P<enumeration_id>[0-9a-z]+)/'
+        + r'(?P<value_id>[0-9]+)/replace/$',
+        admin_view.replace_enumeration_value,
+        name="telemeta-enumeration-replace"),
 
     # Geographic browsing
     url(r'^geo/$', geo_view.list_continents, name="telemeta-geo-continents"),
@@ -268,29 +280,6 @@ urlpatterns = patterns('',
     url(r'^geo/country_info/(?P<id>[0-9a-z]+)/$',
         geo_view.country_info, name="telemeta-country-info"),
 
-    # CSS+Images (FIXME: for developement only)
-    url(r'^css/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': htdocs+'/css'},
-        name="telemeta-css"),
-    url(r'images/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': htdocs+'/images'},
-        name="telemeta-images"),
-    url(r'images/(?P<path>.*).png$', 'django.views.static.serve',
-        {'document_root': htdocs+'/images'},
-        name="telemeta-type-images"),
-    url(r'^js/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': htdocs+'/js'},
-        name="telemeta-js"),
-    url(r'^swf/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': htdocs+'/swf'},
-        name="telemeta-swf"),
-    url(r'^timeside/(?P<path>.*)$', 'django.views.static.serve',
-        {'document_root': htdocs+'/timeside'},
-        name="telemeta-timeside"),
-    url(r'^video-js/(?P<path>.*)$','django.views.static.serve',
-        {'document_root': htdocs+'/video-js'},
-        name="telemeta-video-js"),
-
     # Flat pages
     url(r'^pages/(?P<path>.*)$', home_view.render_flatpage, name="telemeta-flatpage"),
 
@@ -344,6 +333,8 @@ urlpatterns = patterns('',
     # FIXME:need to move export dir from the cache
     url(r'^media/cache/(?P<path>.*)$', 'django.views.static.serve', {
             'document_root': settings.TELEMETA_CACHE_DIR,}),
+
+    url(r'^', include('jqchat.urls')),
 )
 
 
