@@ -38,7 +38,7 @@ import mimetypes
 from telemeta.views.core import *
 
 class ItemView(object):
-    """Provide Collections web UI methods"""
+    """Provide Item web UI methods"""
 
     graphers = timeside.core.processors(timeside.api.IGrapher)
     decoders = timeside.core.processors(timeside.api.IDecoder)
@@ -47,8 +47,20 @@ class ItemView(object):
     cache_data = TelemetaCache(settings.TELEMETA_DATA_CACHE_DIR)
     cache_export = TelemetaCache(settings.TELEMETA_EXPORT_CACHE_DIR)
 
+    export_enabled = getattr(settings, 'TELEMETA_DOWNLOAD_ENABLED', True)
+    export_formats = getattr(settings, 'TELEMETA_DOWNLOAD_FORMATS', ('mp3', 'wav'))
+
+    def get_export_formats(self):
+        formats = []
+        for encoder in self.encoders:
+            if encoder.file_extension() in self.export_formats:
+                formats.append({'name': encoder.format(),
+                                    'extension': encoder.file_extension()})
+        return formats
+
     def item_previous_next(self, item):
-        # Get previous and next items
+        """Get previous and next items inside the collection of the item"""
+
         pks = []
         items = MediaItem.objects.filter(collection=item.collection)
         items = items.order_by('code', 'old_code')
@@ -84,6 +96,7 @@ class ItemView(object):
                         template='telemeta/mediaitem_detail.html'):
         """Show the details of a given item"""
 
+        # get item with one of its given marker_id
         if not public_id and marker_id:
             marker = MediaItemMarker.objects.get(public_id=marker_id)
             item_id = marker.item_id
@@ -91,44 +104,33 @@ class ItemView(object):
         else:
             item = MediaItem.objects.get(public_id=public_id)
 
-        item_public_access = item.public_access != 'none' or item.collection.public_access != 'none'
-        if not item_public_access and not (request.user.is_staff or request.user.is_superuser):
+        access = get_item_access(item, request.user)
+
+        if access == 'none':
             mess = ugettext('Access not allowed')
             title = ugettext('Item') + ' : ' + public_id + ' : ' + mess
             description = ugettext('Please login or contact the website administator to get a private access.')
             messages.error(request, title)
             return render(request, 'telemeta/messages.html', {'description' : description})
 
-        # Get TimeSide processors
-        formats = []
-        for encoder in self.encoders:
-            if settings.TELEMETA_DOWNLOAD_FORMATS:
-                if encoder.file_extension() in settings.TELEMETA_DOWNLOAD_FORMATS:
-                    formats.append({'name': encoder.format(), 'extension': encoder.file_extension()})
-            else:
-                formats.append({'name': encoder.format(), 'extension': encoder.file_extension()})
-
         graphers = []
         for grapher in self.graphers:
             graphers.append({'name':grapher.name(), 'id': grapher.id()})
+            
         if request.REQUEST.has_key('grapher_id'):
             grapher_id = request.REQUEST['grapher_id']
         else:
-            try:
-                grapher_id = settings.TELEMETA_DEFAULT_GRAPHER_ID
-            except:
-                grapher_id = 'waveform'
+            grapher_id = getattr(settings, 'TELEMETA_DEFAULT_GRAPHER_ID', 'waveform')
 
         previous, next = self.item_previous_next(item)
+
         mime_type = self.item_analyze(item)
+
         #FIXME: use mimetypes.guess_type
         if 'quicktime' in mime_type:
             mime_type = 'video/mp4'
 
         playlists = get_playlists(request)
-        public_access = get_public_access(item.public_access, str(item.recorded_from_date).split('-')[0],
-                                                str(item.recorded_to_date).split('-')[0])
-
         related_media = MediaItemRelated.objects.filter(item=item)
         check_related_media(related_media)
         revisions = Revision.objects.filter(element_type='item', element_id=item.id).order_by('-time')
@@ -142,11 +144,11 @@ class ItemView(object):
             format = item.format.get()
 
         return render(request, template,
-                    {'item': item, 'export_formats': formats,
+                    {'item': item, 'export_formats': self.get_export_formats(),
                     'visualizers': graphers, 'visualizer_id': grapher_id,
-                    'audio_export_enabled': getattr(settings, 'TELEMETA_DOWNLOAD_ENABLED', True),
+                    'audio_export_enabled': self.export_enabled,
                     'previous' : previous, 'next' : next, 'marker': marker_id, 'playlists' : playlists,
-                    'public_access': public_access, 'width': width, 'height': height,
+                    'access': access, 'width': width, 'height': height,
                     'related_media': related_media, 'mime_type': mime_type, 'last_revision': last_revision,
                     'format': format,
                     })
@@ -155,12 +157,7 @@ class ItemView(object):
     def item_edit(self, request, public_id, template='telemeta/mediaitem_edit.html'):
         """Edit a given item"""
         item = MediaItem.objects.get(public_id=public_id)
-
-        formats = []
-        for encoder in self.encoders:
-            #FIXME: timeside cannot encode to FLAC and OGG now :'(
-            if encoder.file_extension() != 'ogg' and encoder.file_extension() != 'flac':
-                formats.append({'name': encoder.format(), 'extension': encoder.file_extension()})
+        access = get_item_access(item, request.user)
 
         graphers = []
         for grapher in self.graphers:
@@ -208,10 +205,12 @@ class ItemView(object):
         forms = [item_form, format_form]
 
         return render(request, template,
-                    {'item': item, 'export_formats': formats,
+                    {'item': item,
+                     'export_formats': self.get_export_formats(),
                     'visualizers': graphers, 'visualizer_id': grapher_id,
-                    'audio_export_enabled': getattr(settings, 'TELEMETA_DOWNLOAD_ENABLED', True),
-                    'forms': forms, 'previous' : previous, 'next' : next, 'mime_type': mime_type,
+                    'audio_export_enabled': self.export_enabled,
+                    'forms': forms, 'previous' : previous,
+                    'next' : next, 'mime_type': mime_type, 'access': access,
                     })
 
     def related_media_item_stream(self, request, item_public_id, media_id):
@@ -239,12 +238,15 @@ class ItemView(object):
     @method_decorator(permission_required('telemeta.add_mediaitem'))
     def item_add(self, request, public_id=None, template='telemeta/mediaitem_add.html'):
         """Add an item"""
+        access = ''
+
         if public_id:
             collection = MediaCollection.objects.get(public_id=public_id)
             items = MediaItem.objects.filter(collection=collection)
             code = auto_code(items, collection.code)
             item = MediaItem(collection=collection, code=code)
             format, created = Format.objects.get_or_create(item=item)
+            access = get_item_access(item, request.user)
         else:
             item = MediaItem()
             format = Format()
@@ -268,20 +270,30 @@ class ItemView(object):
         forms = [item_form, format_form]
         hidden_fields = ['item-copied_from_item', 'format-item']
 
-        return render(request, template, {'item': item, 'forms': forms, 'hidden_fields': hidden_fields,})
+        return render(request, template, {'item': item, 'forms': forms, 'hidden_fields': hidden_fields,
+                                            'access': access, })
 
     @method_decorator(permission_required('telemeta.add_mediaitem'))
     def item_copy(self, request, public_id, template='telemeta/mediaitem_copy.html'):
         """Copy a given item"""
         if request.method == 'POST':
             source_item = MediaItem.objects.get(public_id=public_id)
-            item = MediaItem()
+
             format = Format()
-            item_form = MediaItemForm(data=request.POST, files=request.FILES, instance=item, prefix='item')
             format_form = FormatForm(data=request.POST, instance=format, prefix='format')
 
+            item = MediaItem()
+            if request.FILES:
+                item_form = MediaItemForm(data=request.POST, files=request.FILES, instance=item, prefix='item')
+            else:
+                item_form = MediaItemForm(data=request.POST, instance=item, prefix='item')
+
             if item_form.is_valid():
                 item_form.save()
+                if not request.FILES:
+                    item.file = source_item.file
+                    item.save()
+
                 code = item_form.cleaned_data['code']
                 if not code:
                     code = str(item.id)
@@ -316,10 +328,12 @@ class ItemView(object):
             item_form.code = item.code
             item_form.file = None
 
+        access = get_item_access(item, request.user)
         forms = [item_form, format_form]
         hidden_fields = ['item-copied_from_item', 'format-item']
 
-        return render(request, template, {'item': item, "forms": forms, 'hidden_fields': hidden_fields,})
+        return render(request, template, {'item': item, "forms": forms, 'hidden_fields': hidden_fields,
+                                            'access': access, })
 
     @method_decorator(permission_required('telemeta.delete_mediaitem'))
     def item_delete(self, request, public_id):
@@ -349,7 +363,7 @@ class ItemView(object):
             analyzers_sub = []
             graphers_sub = []
 
-            if item.file:
+            if item.file and os.path.exists(item.file.path):
                 decoder  = timeside.decoder.FileDecoder(item.file.path)
                 pipe = decoder
 
@@ -448,7 +462,7 @@ class ItemView(object):
                 (decoder | graph).run()
                 graph.watermark('timeside', opacity=.6, margin=(5,5))
                 f = open(path, 'w')
-                graph.render(path)
+                graph.render(output=path)
                 f.close()
 
         response = HttpResponse(self.cache_data.read_stream_bin(image_file), mimetype=mime_type)
@@ -467,11 +481,9 @@ class ItemView(object):
         """Export a given media item in the specified format (OGG, FLAC, ...)"""
 
         item = MediaItem.objects.get(public_id=public_id)
-        public_access = get_public_access(item.public_access,
-                                          str(item.recorded_from_date).split('-')[0],
-                                          str(item.recorded_to_date).split('-')[0])
+        public_access = get_item_access(item, request.user)
 
-        if (not public_access or not extension in settings.TELEMETA_STREAMING_FORMATS) and \
+        if (not public_access == 'full' or not extension in settings.TELEMETA_STREAMING_FORMATS) and \
                     not (request.user.has_perm('telemeta.can_play_all_items') or request.user.is_superuser):
             mess = ugettext('Access not allowed')
             title = 'Item file : ' + public_id + '.' + extension + ' : ' + mess
@@ -521,7 +533,7 @@ class ItemView(object):
         if mime_type in format:
             # source > stream
             if not extension in mapping.unavailable_extensions:
-                proc = encoder(audio)
+                proc = encoder(audio, overwrite=True)
                 proc.set_metadata(metadata)
                 try:
                     proc.write_metadata()
@@ -534,7 +546,7 @@ class ItemView(object):
                 # source > encoder > stream
                 decoder = self.decoders[0](audio)
                 decoder.setup()
-                proc = encoder(media, streaming=True)
+                proc = encoder(media, streaming=True, overwrite=True)
                 proc.setup(channels=decoder.channels(), samplerate=decoder.samplerate())
                 if extension in mapping.unavailable_extensions:
                     metadata=None
